pub struct ColumnDiff {
pub name: String,
pub ch_type: String,
}Expand description
A column the kit declares that the live table is missing. ch_type is the
trusted ClickHouse type derived from the kit’s TableSpec, not from live.
Fields
name: Stringch_type: StringTrait Implementations
Sourceimpl Clone for ColumnDiff
impl Clone for ColumnDiff
Sourcefn clone(&self) -> ColumnDiff
fn clone(&self) -> ColumnDiff
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ColumnDiff
impl Debug for ColumnDiff
impl Eq for ColumnDiff
Sourceimpl PartialEq for ColumnDiff
impl PartialEq for ColumnDiff
Sourcefn eq(&self, other: &ColumnDiff) -> bool
fn eq(&self, other: &ColumnDiff) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ColumnDiff